@@ -3,4 +3,4 @@ from .pure import *
 try:
     from .django import *
 except Exception as e:
-    warn('导入django失败--- ' + str(e))
\ No newline at end of file
+    warn('导入django失败? --- ' + str(e))
\ No newline at end of file
